==> dca_sm_sdk-0.0.10.tar.gz: dca_sm_sdk-0.0.10/src/dca_sm_sdk/state_machine.py <==
import datetime

import nuclio_sdk
from abc import ABC, abstractmethod

from dca_sm_sdk.mts_state import MtsState


class IState(ABC):
    @abstractmethod
    def Action(self, context : nuclio_sdk.Context ,mts_state: MtsState) -> str:
        pass

class StateMachine:
    def __init__(self, context : nuclio_sdk.Context):
        self.current_state = ""
        self.states = {}
        self.mts_state = MtsState()
        self.context = context


    def RegisterState(self, state_mame: str, state: IState):
        if state_mame in self.states:
            raise Exception(f"State {state_mame} registered")
        self.states[state_mame] = state
        self.context.logger.info(f"State {state_mame} registered")


    def SetStartState(self, state_name: str):
        if state_name not in self.states:
            raise Exception(f"State {state_name} not registered")
        self.current_state = state_name
        self.context.logger.info(f"State {state_name} set start")

    def Execute(self, context : nuclio_sdk.Context, event : nuclio_sdk.Event):
        print(event)
        print(event.body)
        prev_state = self.current_state
        state = self.states[self.current_state]
        try:
            self.mts_state.UpdateMtsState(self.mts_state, event)
            self.current_state = state.Action(context, self.mts_state)
            self.context.logger.info(f"State {prev_state} executed")
            return self.mts_state
        except Exception as e:
            context.logger.error_with(f"State {prev_state} failed with exception {e}", )

==> dca_sm_sdk-0.0.14.tar.gz: dca_sm_sdk-0.0.14/src/dca_sm_sdk/state_machine.py <==
import datetime

import nuclio_sdk
from abc import ABC, abstractmethod

from dca_sm_sdk.mts_state import MtsState


class IState(ABC):
    @abstractmethod
    def Action(self, context : nuclio_sdk.Context ,mts_state: MtsState) -> str:
        pass

class StateMachine:
    def __init__(self, context : nuclio_sdk.Context):
        self.current_state = ""
        self.states = {}
        self.mts_state = MtsState()
        self.context = context


    def RegisterState(self, state_mame: str, state: IState):
        if state_mame in self.states:
            raise Exception(f"State {state_mame} registered")
        self.states[state_mame] = state
        self.context.logger.info(f"State {state_mame} registered")


    def SetStartState(self, state_name: str):
        if state_name not in self.states:
            raise Exception(f"State {state_name} not registered")
        self.current_state = state_name
        self.context.logger.info(f"State {state_name} set start")

    def Execute(self, context : nuclio_sdk.Context, event : nuclio_sdk.Event):
        prev_state = self.current_state
        state = self.states[self.current_state]
        try:
            self.mts_state.UpdateMtsState(event)
            self.current_state = state.Action(context, self.mts_state)
            self.context.logger.info(f"State {prev_state} executed")
            result = self.mts_state

            return result
        except Exception as e:
            context.logger.error_with(f"State {prev_state} failed with exception {e}")
            return nuclio_sdk.Response(f"State {prev_state} failed with exception {e}")
